# Changelog

All notable changes to this project will be documented in this file. See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## 1.0.0 (2025-12-25)


### Features

* enhance configuration support with environment variables and update README ([#6](https://github.com/fligneul/hyponcloud2mqtt/issues/6)) ([dc01bec](https://github.com/fligneul/hyponcloud2mqtt/commit/dc01bec3b35040c353bf370ce5be42fe365c188f))
* **mqtt:** add LWT and remove individual topics ([27575b3](https://github.com/fligneul/hyponcloud2mqtt/commit/27575b3552ce89deb4220ef3ba030b6ee770de47))
* **mqtt:** add SSL/TLS support and update configuration example ([#2](https://github.com/fligneul/hyponcloud2mqtt/issues/2)) ([2ccf572](https://github.com/fligneul/hyponcloud2mqtt/commit/2ccf572143f3124d6e8d6efe91b8e004da22b5e4))
* Restructure project, introduce comprehensive testing with WireMock, and implement new CI/CD workflows for release automation. ([2cf2e4c](https://github.com/fligneul/hyponcloud2mqtt/commit/2cf2e4ca12085e771fc5335ac481bf024feac3f8))


### Documentation

* update README configuration example ([a3da9f9](https://github.com/fligneul/hyponcloud2mqtt/commit/a3da9f97ebe31b5fe8bc47016ac579eabcbf12aa))
* Update README with correct Python version and AGPLv3 license information. ([50121dc](https://github.com/fligneul/hyponcloud2mqtt/commit/50121dc71acef24260f963533beafdbbe300f581))
* update REAME ([2923aa3](https://github.com/fligneul/hyponcloud2mqtt/commit/2923aa3ce6f652bac00cc1ad1f2e6cb80c4f9b40))

## [Unreleased]
